// © 2016 and later: Unicode, Inc. and others.
// License & terms of use: http://www.unicode.org/copyright.html
/********************************************************************
 * COPYRIGHT:
 * Copyright (c) 2007-2014, International Business Machines Corporation and
 * others. All Rights Reserved.
 ********************************************************************/


/**  Auto-client **/
#define UCLN_TYPE UCLN_TOOLUTIL
#include "ucln_imp.h"

int uprv_dummyFunction_TU();
int uprv_dummyFunction_TU()
{
  /* this is here to prevent the compiler from complaining about an empty file */
  return 0;
}
